import {Component, Input, OnInit, SimpleChanges} from '@angular/core';
import {Event} from '../../models/event';

@Component({
    selector: 'app-week',
    templateUrl: './week.component.html',
    styleUrls: ['./week.component.css']
})
export class WeekComponent implements OnInit {
    @Input() events: Event[] = [];
    @Input() showDeletedEvents: boolean = true;
    eventsPerDay: Event[][] = [];

    constructor() {
    }

    ngOnInit(): void {
        this.splitEventsIntoDays();
    }

    ngOnChanges(changes: SimpleChanges): void {
        this.splitEventsIntoDays();
    }

    /**
     * Splits the given events into their days so we have a list of events for every day of the week
     * to pass into the day components
     */
    splitEventsIntoDays() {
        // Pre-fill list with 7 empty days
        this.eventsPerDay = [];
        for(let day = 0; day < 7; day++) {
            this.eventsPerDay.push([]);
        }

        this.events.forEach((event) => {
            let startDate = new Date(event.latest_start_date);
            let year = startDate.getFullYear().toString();
            let month = startDate.getMonth().toString().padStart(2, '0');
            let day = startDate.getDate().toString().padStart(2, '0');
            let dayIndex = startDate.getDay();
            // Because these start with fucking sunday
            if(dayIndex === 0) {
                dayIndex = 6;
            } else {
                dayIndex--;
            }

            this.eventsPerDay[dayIndex].push(event);
        });
    }

}
