import {Component, OnInit} from '@angular/core';
import {ApiService} from '../../services/api/api.service';
import {Event} from '../../models/event';

@Component({
    selector: 'app-landingpage',
    templateUrl: './landingpage.component.html',
    styleUrls: ['./landingpage.component.css']
})
export class LandingpageComponent implements OnInit {
    events: Event[] = [];
    eventCount: number = 0;

    selectedDate: string = '';
    showDeletedEvents: boolean = true;

    constructor(
        private apiService: ApiService
    ) {
    }

    ngOnInit(): void {
    }

    /**
     * Fetches the events for the currently selected date from the API
     */
    getEvents() {
        this.apiService.getEvents(this.selectedDate).subscribe(events => {
            this.events = events;
            this.eventCount = events.length;
        });
    }

    /**
     * Called when the selected date is changed in the datepicker component.
     * Fetches the events for the new date
     * @param newDate The new date to get the events for
     */
    dateChangedFromPicker(newDate: string) {
        this.selectedDate = newDate;
        this.getEvents();
    }

    /**
     * Called when the state of "show deleted events" is changed in the datepicker component.
     * Passes the new value to the underlying components
     * @param newShowDeleted The new state of "show deleted events"
     */
    showDeletedChangedFromPicker(newShowDeleted: boolean) {
        this.showDeletedEvents = newShowDeleted;
    }
}
