import {Injectable} from '@angular/core';
import {HttpClient, HttpParams} from '@angular/common/http';
import {Observable} from 'rxjs';
import {Event} from '../../models/event';

@Injectable({
    providedIn: 'root'
})
export class ApiService {
    apiUrl = 'https://api.plutodev.de/raplachanges/';

    constructor(
        private http: HttpClient
    ) {
    }

    /*
        ______     __     ________
       / ____/__  / /_   / ____/ /_  ____ _____  ____ ____  _____
      / / __/ _ \/ __/  / /   / __ \/ __ `/ __ \/ __ `/ _ \/ ___/
     / /_/ /  __/ /_   / /___/ / / / /_/ / / / / /_/ /  __(__  )
     \____/\___/\__/   \____/_/ /_/\__,_/_/ /_/\__, /\___/____/
                                              /____/
     */

    /**
     * Gets all events and their corresponding changes for the given week.
     * Best to supply only dates which are a monday, although other days are possible as well
     * @param week The week to fetch the events for
     * @return Observable<Event[]> A list of events
     */
    getEvents(week: string): Observable<Event[]> {
        try {
            let params = new HttpParams();
            params = params.append('week', week);
            return this.http.get<Event[]>((this.apiUrl), {params});
        } catch (exception) {
            console.log('Error fetching events from API');
        }
        return new Observable<Event[]>();
    }

    /**
     * Gets the event details for the specified event
     * @param id The UID of the event as saved in SQL
     * @return Observable<Event> The single event
     */
    getEventById(id: string): Observable<Event> {
        try {
            return this.http.get<Event>((this.apiUrl + '/' + id));
        } catch (exception) {
            console.log('Error fetching events from API');
        }
        return new Observable<Event>();
    }
}
