import {Injectable} from '@angular/core';

@Injectable({
    providedIn: 'root'
})
export class UtilitiesService {

    constructor() {
    }

    /**
     * Get the formatted time for the given date
     * @param date The date to format the time for
     * @return string the formatted time in the format HH:MM (24h format)
     */
    getTimeFromDate(date: Date): string {
        return date.getHours().toString().padStart(2, '0') + ':' + date.getMinutes().toString().padStart(2, '0');
    }

    /**
     * Get the formatted time for the given date
     * @param dateString The date as a string to format the time for
     * @return string the formatted time in the format HH:MM (24h format)
     */
    getTimeFromString(dateString: string): string {
        let date = new Date(dateString);
        return this.getTimeFromDate(date);
    }

    /**
     * Formats the given date
     * @param date The date to format
     * @return string the formatted date in the format DD.mm.YY, HH:MM (24h format)
     */
    getDateTimeFromDate(date: Date): string {
        let year = date.getFullYear().toString();
        let month = date.getMonth().toString().padStart(2, '0');
        let day = date.getDate().toString().padStart(2, '0');
        let hour = date.getHours().toString().padStart(2, '0');
        let minute = date.getMinutes().toString().padStart(2, '0');

        return day + '.' + month + '.' + year + ', ' + hour + ':' + minute;
    }

    /**
     * Formats the given date
     * @param dateString The date as a string to format
     * @return string the formatted date in the format DD.mm.YY, HH:MM (24h format)
     */
    getDateTimeFromString(dateString: string): string {
        let date = new Date(dateString);
        return this.getDateTimeFromDate(date);
    }
}
